==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/GetEventSubscriptionFullUrlPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.GetEventSubscriptionFullUrlPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property eventSubscriptionName Name of the event subscription.
 * @property scope The scope of the event subscription. The scope can be a subscription, or a resource group, or a top level resource belonging to a resource provider namespace, or an EventGrid topic. For example, use '/subscriptions/{subscriptionId}/' for a subscription, '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}' for a resource group, and '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}' for a resource, and '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.EventGrid/topics/{topicName}' for an EventGrid topic.
 */
public data class GetEventSubscriptionFullUrlPlainArgs(
    public val eventSubscriptionName: String,
    public val scope: String,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.GetEventSubscriptionFullUrlPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.eventgrid.inputs.GetEventSubscriptionFullUrlPlainArgs =
        com.pulumi.azurenative.eventgrid.inputs.GetEventSubscriptionFullUrlPlainArgs.builder()
            .eventSubscriptionName(eventSubscriptionName.let({ args0 -> args0 }))
            .scope(scope.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetEventSubscriptionFullUrlPlainArgs].
 */
@PulumiTagMarker
public class GetEventSubscriptionFullUrlPlainArgsBuilder internal constructor() {
    private var eventSubscriptionName: String? = null

    private var scope: String? = null

    /**
     * @param value Name of the event subscription.
     */
    @JvmName("bjohmbqrbneudgye")
    public suspend fun eventSubscriptionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.eventSubscriptionName = mapped
    }

    /**
     * @param value The scope of the event subscription. The scope can be a subscription, or a resource group, or a top level resource belonging to a resource provider namespace, or an EventGrid topic. For example, use '/subscriptions/{subscriptionId}/' for a subscription, '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}' for a resource group, and '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}' for a resource, and '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.EventGrid/topics/{topicName}' for an EventGrid topic.
     */
    @JvmName("avltnkjqxdhqndms")
    public suspend fun scope(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.scope = mapped
    }

    internal fun build(): GetEventSubscriptionFullUrlPlainArgs = GetEventSubscriptionFullUrlPlainArgs(
        eventSubscriptionName = eventSubscriptionName ?: throw
            PulumiNullFieldException("eventSubscriptionName"),
        scope = scope ?: throw PulumiNullFieldException("scope"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/GetEventSubscriptionFullUrlPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.GetEventSubscriptionFullUrlPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property eventSubscriptionName Name of the event subscription.
 * @property scope The scope of the event subscription. The scope can be a subscription, or a resource group, or a top level resource belonging to a resource provider namespace, or an EventGrid topic. For example, use '/subscriptions/{subscriptionId}/' for a subscription, '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}' for a resource group, and '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}' for a resource, and '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.EventGrid/topics/{topicName}' for an EventGrid topic.
 */
public data class GetEventSubscriptionFullUrlPlainArgs(
    public val eventSubscriptionName: String,
    public val scope: String,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.GetEventSubscriptionFullUrlPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.eventgrid.inputs.GetEventSubscriptionFullUrlPlainArgs =
        com.pulumi.azurenative.eventgrid.inputs.GetEventSubscriptionFullUrlPlainArgs.builder()
            .eventSubscriptionName(eventSubscriptionName.let({ args0 -> args0 }))
            .scope(scope.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetEventSubscriptionFullUrlPlainArgs].
 */
@PulumiTagMarker
public class GetEventSubscriptionFullUrlPlainArgsBuilder internal constructor() {
    private var eventSubscriptionName: String? = null

    private var scope: String? = null

    /**
     * @param value Name of the event subscription.
     */
    @JvmName("ejkgssjtwyxnbrmf")
    public suspend fun eventSubscriptionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.eventSubscriptionName = mapped
    }

    /**
     * @param value The scope of the event subscription. The scope can be a subscription, or a resource group, or a top level resource belonging to a resource provider namespace, or an EventGrid topic. For example, use '/subscriptions/{subscriptionId}/' for a subscription, '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}' for a resource group, and '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}' for a resource, and '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.EventGrid/topics/{topicName}' for an EventGrid topic.
     */
    @JvmName("oonatjdpkqpybwrq")
    public suspend fun scope(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.scope = mapped
    }

    internal fun build(): GetEventSubscriptionFullUrlPlainArgs = GetEventSubscriptionFullUrlPlainArgs(
        eventSubscriptionName = eventSubscriptionName ?: throw
            PulumiNullFieldException("eventSubscriptionName"),
        scope = scope ?: throw PulumiNullFieldException("scope"),
    )
}
